" Unified API for current and obsolete python-dbus APIs "

try:
	import dbus
	if hasattr(dbus, 'version') and dbus.version >= (0, 40, 0):
		DBusException = dbus.DBusException
	else:
		DBusException = dbus.dbus_bindings.DBusException
	# Else, using D-BUS 0.2
except ImportError:
	rox.alert("Failed to import dbus module. You probably need "
		"to install a package with a name like 'python-dbus'.\n\n"
		"D-BUS can also be downloaded from http://freedesktop.org\n"
		"(be sure to compile the python and glib bindings)\n\n"
		"If the bindings are installed in /usr/local/lib/python...,"
		"try moving them to /usr/lib/python... (without the 'local')")
	raise


class ProxyObject:
	def __init__(self, obj):
		self.__obj = obj
	
	def ListNames(self):
		if hasttr(self.__obj, "ListNames"):
			return self.__obj.ListNames()
		else:
			return self.__obj.ListServices()

	def __get_attr__(self, attr):
		return getattr(self.__obj, attr)


class SessionBus:
	def __init__(self):
		if hasattr(dbus, "SessionBus"):
			self.__bus = dbus.SessionBus()
		else:
			self.__bus = dbus.Bus(dbus.Bus.TYPE_SESSION)
	
	def get_object(self, bus_name, object_path, interface = None):
		if hasattr(self.__bus, "get_object"):
			return self.__bus.get_object(bus_name, object_path)
		else:
			if not interface:
				interface = bus_name
			service = self.__bus.get_service(bus_name)
			obj = service.get_object(object_path, interface)
		return ProxyObject(obj)

	def __get_attr__(self, attr):
		return getattr(self.__bus, attr)


if hasattr(dbus, "Interface"):
	Interface = dbus.Interface
else:
	def Interface(object, interface = None):
		return object

